package com.me.pacman;

import com.badlogic.gdx.Game;
import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.graphics.GL20;
import com.badlogic.gdx.graphics.OrthographicCamera;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.utils.viewport.FitViewport;
import com.badlogic.gdx.utils.viewport.Viewport;
import com.me.pacman.state.MenuState;

public class PacDude extends Game {

	public static final String TITLE = "Pac-Dude";
	public static final String VERSION = "v0.1.0";

	public static final boolean DEBUG = false;

	public static final int LEVEL_WIDTH = 224;
	public static final int LEVEL_HEIGHT = 288;

	public Assets assets;
	public Sound sound;

	public SpriteBatch batch;

	public OrthographicCamera cam;
	public Viewport viewport;

	@Override
	public void create () {
		cam = new OrthographicCamera();
		viewport = new FitViewport(LEVEL_WIDTH, LEVEL_HEIGHT, cam);
		viewport.apply(true);

		assets = new Assets();
		assets.loadAssets();
		sound = new Sound(this);

		batch = new SpriteBatch();

		Gdx.gl.glClearColor(0, 0, 0, 1);
		setScreen(new MenuState(this));
	}

	@Override
	public void render () {
		Gdx.gl.glClear(GL20.GL_COLOR_BUFFER_BIT);

		batch.begin();
		if (DEBUG) {
			assets.getFont().draw(batch, "FPS: " + Gdx.graphics.getFramesPerSecond(), 152, 287);
		}
		super.render();
		batch.end();
	}

	@Override
	public void resize(int width, int height) {
		viewport.update(width, height);

		batch.setProjectionMatrix(cam.combined);

		super.resize(width, height);
	}

	@Override
	public void dispose () {
		batch.dispose();
		assets.dispose();
	}
}
