package com.me.pacman.state;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Input;
import com.badlogic.gdx.InputAdapter;
import com.badlogic.gdx.graphics.Color;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.BitmapFont;
import com.me.pacman.PacDude;
import com.me.pacman.Sound;

public class MenuState extends LevelState {

    private Texture levelBackground;
    private Texture logo;
    private BitmapFont font;


    public static final int NEW_GAME = 0;
    public static final int HIGH_SCORES = 1;

    private static final int MENU_PADDING = 24;
    private static final int MENU_X = 84;
    private static final int MENU_Y = 85;

    private int selectedOption;
    private static final String[] options = {
            "New Game",
            "High Scores",
    };


    public MenuState(PacDude game) {
        super(game);
    }

    @Override
    public void setup() {
        levelBackground = game.assets.getMenuBackground();
        logo = game.assets.getLogo();
        logo.setFilter(Texture.TextureFilter.Linear, Texture.TextureFilter.Linear);
        font = game.assets.getFont();

        Gdx.input.setInputProcessor(this.new Controller());

        game.sound.play(Sound.Effect.BEGINNING);
    }

    @Override
    public void render() {
        game.batch.draw(levelBackground, 0, 16);
        game.batch.draw(logo, 0, 140, 224, 120);

        for (int i = 0; i < options.length; i++) {
            font.setColor(i == selectedOption? Color.BLUE : Color.WHITE);

            font.draw(game.batch, options[i], MENU_X, MENU_Y - (i * MENU_PADDING), 56, 1, true);
        }
    }

    @Override
    public void update(float dt) {}

    private final class Controller extends InputAdapter {

        @Override
        public boolean keyDown(int keycode) {
            switch (keycode) {
                case Input.Keys.UP:
                    selectedOption = selectedOption > 0 ? --selectedOption : options.length - 1;
                    game.sound.play(Sound.Effect.CHOMP_1);
                    break;
                case Input.Keys.DOWN:
                    selectedOption = selectedOption < options.length - 1 ? ++selectedOption : 0;
                    game.sound.play(Sound.Effect.CHOMP_2);
                    break;
                case Input.Keys.ENTER:
                    switch (selectedOption) {
                        case NEW_GAME:
                            game.setScreen(new PlayState(game));
                            break;
                        case HIGH_SCORES:
//                            game.setScreen(new HighScores(game));
                            break;
                    }
                    break;
            }
            return super.keyDown(keycode);
        }

    }

    @Override
    public void dispose() {
        Gdx.input.setInputProcessor(null);
    }

}
